@@ -100,7 +100,7 @@ sub listen {
   %$options = (
     %$options,
     SSL_ca_file => -T $args->{tls_ca} ? $args->{tls_ca} : undef,
-    SSL_verify_mode => 0x03
+    SSL_verify_mode => defined $args->{tls_verify} ? $args->{tls_verify} : 0x03
   ) if $args->{tls_ca};
 }
 
@@ -264,6 +264,10 @@ Path to the TLS cert file, defaults to a built-in test certificate.
 
 Path to the TLS key file, defaults to a built-in test key.
 
+=item C<tls_verify>
+
+TLS verification mode, defaults to C<0x03>.
+
 =back
 
 =head2 C<generate_port>
