@@ -11,8 +11,7 @@ sub register {
   my ($self, $app, $conf) = @_;
 
   # Auto escape by default to prevent XSS attacks
-  my $template = $conf->{template} || {};
-  $template->{auto_escape} //= 1;
+  my $template = {auto_escape => 1, %{$conf->{template} || {}}};
 
   # Add "ep" handler
   $app->renderer->add_handler(
@@ -25,7 +24,7 @@ sub register {
       my $id = encode 'UTF-8', join(', ', $path, sort keys %{$c->stash});
       my $key = $options->{cache} = md5_sum $id;
 
-      # Cache
+      # Compile helpers and stash values
       my $cache = $r->cache;
       unless ($cache->get($key)) {
         my $mt = Mojo::Template->new($template);
@@ -36,30 +35,22 @@ sub register {
 
         # Helpers
         $prepend .= 'my $_H = $self->app->renderer->helpers;';
-        for my $name (sort keys %{$r->helpers}) {
-          next unless $name =~ /^\w+$/;
-          $prepend .= "sub $name; *$name = sub { ";
-          $prepend .= "\$_H->{'$name'}->(\$self, \@_) };";
-        }
+        $prepend .= "sub $_; *$_ = sub { \$_H->{'$_'}->(\$self, \@_) };"
+          for grep {/^\w+$/} keys %{$r->helpers};
 
         # Be less relaxed for everything else
         $prepend .= 'use strict;';
 
         # Stash
         $prepend .= 'my $_S = $self->stash;';
-        for my $var (keys %{$c->stash}) {
-          next unless $var =~ /^\w+$/;
-          $prepend .= " my \$$var = \$_S->{'$var'};";
-        }
-
-        # Prepend generated code
-        $mt->prepend($prepend);
+        $prepend .= " my \$$_ = \$_S->{'$_'};"
+          for grep {/^\w+$/} keys %{$c->stash};
 
         # Cache
-        $cache->set($key => $mt);
+        $cache->set($key => $mt->prepend($prepend));
       }
 
-      # Render with epl
+      # Render with "epl" handler
       return $r->handlers->{epl}->($r, $c, $output, $options);
     }
   );
